==> haskell-blaze-textual-0.2.3.1-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 blaze-textual
version:              0.2.3.1
visibility:           public
id:                   blaze-textual-0.2.3.1-C6zdLXM4DzV2EGvPAQVYMC
key:                  blaze-textual-0.2.3.1-C6zdLXM4DzV2EGvPAQVYMC
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:           Andrey Prokopenko <persiantiger@yandex.ru>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/swamp-agr/blaze-textual
synopsis:             Fast rendering of common datatypes
description:
    A library for efficiently rendering Haskell datatypes to
    bytestrings.

    /Note/: if you use GHCi or Template Haskell, please see the
    @README@ file for important details about building this package,
    and other packages that depend on it:
    <https://github.com/swamp-agr/blaze-textual#readme>

category:             Text
abi:                  d3dea83cde0e138a9f1e0ec832661997
exposed:              True
exposed-modules:      Blaze.Text Blaze.Text.Double Blaze.Text.Int
hidden-modules:       Blaze.Text.Double.Native
import-dirs:          /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-textual
hs-libraries:         HSblaze-textual-0.2.3.1-C6zdLXM4DzV2EGvPAQVYMC
depends:
    base-4.17.2.1 blaze-builder-0.4.3-KajDOuS86PHBEcDCbLATP7
    bytestring-0.11.5.3 ghc-prim-0.9.1 integer-gmp-1.1
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh text-2.0.2
    vector-0.13.2.0-5IsJnyR8rmEEUPyguFia6U

haddock-interfaces:
    /usr/share/doc/haskell-blaze-textual/html/blaze-textual.haddock

haddock-html:         /usr/share/doc/haskell-blaze-textual/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-textual-0.2.3.1-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 blaze-textual
version:              0.2.3.1
visibility:           public
id:                   blaze-textual-0.2.3.1-Bn4ktJ70lVFGEtlL1jN9q3
key:                  blaze-textual-0.2.3.1-Bn4ktJ70lVFGEtlL1jN9q3
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:           Andrey Prokopenko <persiantiger@yandex.ru>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/swamp-agr/blaze-textual
synopsis:             Fast rendering of common datatypes
description:
    A library for efficiently rendering Haskell datatypes to
    bytestrings.

    /Note/: if you use GHCi or Template Haskell, please see the
    @README@ file for important details about building this package,
    and other packages that depend on it:
    <https://github.com/swamp-agr/blaze-textual#readme>

category:             Text
abi:                  0908c547ecfc66e9d63b07ff7a14dcc9
exposed:              True
exposed-modules:      Blaze.Text Blaze.Text.Double Blaze.Text.Int
hidden-modules:       Blaze.Text.Double.Native
import-dirs:          /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-textual
hs-libraries:         HSblaze-textual-0.2.3.1-Bn4ktJ70lVFGEtlL1jN9q3
depends:
    base-4.17.2.1 blaze-builder-0.4.3-HXodF8PiFiTI0hprQuztF4
    bytestring-0.11.5.3 ghc-prim-0.9.1 integer-gmp-1.1
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh text-2.0.2
    vector-0.13.2.0-5H8NMvQc0Ab8bNH9ZMgAUW

haddock-interfaces:
    /usr/share/doc/haskell-blaze-textual/html/blaze-textual.haddock

haddock-html:         /usr/share/doc/haskell-blaze-textual/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
